*****
smore
*****

.. image:: https://travis-ci.org/marshmallow-code/smore.svg?branch=dev
    :target: https://travis-ci.org/marshmallow-code/smore

**EXPERIMENTAL: Nothing here is stable. Right now this is just a playground to try out some ideas.**

A collection of utilities for designing and documenting RESTful APIs built with  `marshmallow <https://marshmallow.readthedocs.org/en/latest/>`_.


Features
--------

- Convert ``marshmallow.Schemas`` and ``webarg.Args`` into `Swagger 2.0 <http://swagger.io>`_ API definitions
- Pagination (in progress)
- Automatic API documentation (in progress)


Documentation
-------------

Documentation is available at http://smore.readthedocs.org/ .


Projects that graduated from smore
----------------------------------

- `marshmallow-validators <https://github.com/marshmallow-code/marshmallow-validators>`_

License
-------

MIT licensed. See the bundled `LICENSE <https://github.com/marshmallow-code/smore/blob/master/LICENSE>`_ file for more details.
